WheelCMS Axle
=============

This is the 'core' package for WheelCMS. It provides the base implementation
for the content types (spokes), the database tree structure (nodes), search
indexing, userena integration and request handling/dispatching.

It's called Axle, because that's the center of a Wheel :)
